<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sl">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="20"/>
        <source>MX Boot Repair</source>
        <translation>MX popravilo zagona</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="45"/>
        <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the ESP (EFI System Partition), MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR (root).</source>
        <translation>MX popravilo zagona je orodje za ponovno namestitev GRUB zaganjalnika na ESP (EFI sistemski razdelek), MBR (MAster Boot Record) ali korenski razdelek. Ponuja možnost rekonstrukcije GRUB konfiguracijske datoteke in ustvarjanja varnostne kopije MBR ali PBR (koren) ali obnovitev z nje.</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="64"/>
        <source>What would you like to do?</source>
        <translation>Kaj bi radi storili?</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="94"/>
        <source>Backup MBR or PBR (legacy boot only)</source>
        <translation>Varnostno kopiranje MBR ali PBR (samo za legacy zagon)</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="70"/>
        <source>Reinstall GRUB bootloader on ESP, MBR or PBR (root)</source>
        <translation>Ponovno namesti GRUB zaganjalnik na ESP, MPR ali PBR (koren)</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="80"/>
        <source>Repair GRUB configuration file</source>
        <translation>Popravi GRUB konfiguracijo</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="87"/>
        <source>Regenerate initramfs images</source>
        <translation>Poustvari initramfs posnetke</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="101"/>
        <source>Restore MBR or PBR from backup (legacy boot only)</source>
        <translation>Obnovi MBR ali PBR iz varnostne kopije (samo za legacy zagon)</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="134"/>
        <location filename="../src/gui/mainwindow.cpp" line="425"/>
        <source>Select Boot Method</source>
        <translation>Določi zagonski način</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="152"/>
        <source>Master Boot Record</source>
        <translation>Master Boot Record</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="155"/>
        <source>MBR</source>
        <translation>MBR</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="158"/>
        <location filename="../src/gui/mainwindow.ui" line="398"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="193"/>
        <location filename="../src/gui/mainwindow.cpp" line="426"/>
        <source>Location:</source>
        <translation>Lokacija:</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="218"/>
        <source>EFI System Partition</source>
        <translation>EFI sistemski razdelek</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="221"/>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="240"/>
        <source>Root (Partition Boot Record)</source>
        <translation>Koren (Partition Boot Record)</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="243"/>
        <location filename="../src/gui/mainwindow.cpp" line="428"/>
        <source>root</source>
        <translation>koren</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="278"/>
        <location filename="../src/gui/mainwindow.cpp" line="433"/>
        <source>Select root location:</source>
        <translation>Izberite lokacijo za koren:</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="300"/>
        <location filename="../src/gui/mainwindow.cpp" line="427"/>
        <source>Install on:</source>
        <translation>Namesti na:</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="389"/>
        <source>About this application</source>
        <translation>O tem programu</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="392"/>
        <source>About...</source>
        <translation>O programu...</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="440"/>
        <source>Display help </source>
        <translation>Prikaži pomoč</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="443"/>
        <source>Help</source>
        <translation>Pomoč</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="449"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="490"/>
        <source>Cancel any changes then quit</source>
        <translation>Prekliči vse spremembe in končaj</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="493"/>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="499"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="518"/>
        <source>Apply any changes</source>
        <translation>Uveljavi vse spremembe</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="521"/>
        <location filename="../src/gui/mainwindow.cpp" line="82"/>
        <source>Next</source>
        <translation>Naprej</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="461"/>
        <source>Apply</source>
        <translation>Uveljavi</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="102"/>
        <source>GRUB is being installed on %1 device.</source>
        <translation>GRUB se namešča na napravo %1</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="292"/>
        <location filename="../src/gui/mainwindow.cpp" line="350"/>
        <location filename="../src/gui/mainwindow.cpp" line="466"/>
        <location filename="../src/gui/mainwindow.cpp" line="470"/>
        <location filename="../src/gui/mainwindow.cpp" line="477"/>
        <location filename="../src/gui/mainwindow.cpp" line="483"/>
        <location filename="../src/gui/mainwindow.cpp" line="491"/>
        <location filename="../src/gui/mainwindow.cpp" line="498"/>
        <source>Error</source>
        <translation>Napaka</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="142"/>
        <source>The GRUB configuration file (grub.cfg) is being rebuilt.</source>
        <translation>Konfiguracijska datoteka za GRUB (grub.cfg) se ponovno gradi.</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="176"/>
        <source>Generating initramfs images on: %1</source>
        <translation>Ustvarjanje initramfs posnetkov na: %1</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="205"/>
        <source>Backing up MBR or PBR from %1 device.</source>
        <translation>Varnostno kopiranje MBR ali PBR iz naprave %1.</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="261"/>
        <source>Warning</source>
        <translation>Opozorilo</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="262"/>
        <source>You are going to write the content of </source>
        <translation>Zapisali boste vsebino iz </translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="262"/>
        <source> to </source>
        <translation>na</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="263"/>
        <source>

Are you sure?</source>
        <translation>

Ali ste prepričani?</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="269"/>
        <source>Restoring MBR/PBR from backup to %1 device.</source>
        <translation>Obnova MBR/PBR iz varnostne kopije na napravo %1.</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="293"/>
        <source>Could not find EFI system partition (ESP) on any system disks. Please create an ESP and try again.</source>
        <translation>Nisem uspel najti EFI sistemskega razdelka (ESP) ali drug sistemski disk. Prosimo, ustvarite ESP in poskusite znova. </translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="305"/>
        <source>Select %1 location:</source>
        <translation>Izberite lokacijo %1:</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="328"/>
        <source>Back</source>
        <translation>Nazaj</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="344"/>
        <source>Success</source>
        <translation>Uspešno</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="344"/>
        <source>Process finished with success.&lt;p&gt;&lt;b&gt;Do you want to exit MX Boot Repair?&lt;/b&gt;</source>
        <translation>Proces se je uspešno zaključil.&lt;p&gt;&lt;b&gt;Ali želite zapustiti MX popravilo zagona?&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="350"/>
        <source>Process finished. Errors have occurred.</source>
        <translation>Postopek je končan. Pojavile so se napake.</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="109"/>
        <location filename="../src/gui/mainwindow.cpp" line="150"/>
        <location filename="../src/gui/mainwindow.cpp" line="182"/>
        <source>Enter password to unlock %1 encrypted partition:</source>
        <translation>Vnesite geslo za odklep šifriranega razdelka %1:</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="432"/>
        <source>Select GRUB location</source>
        <translation>Določi lokacijo za GRUB</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="441"/>
        <source>Select initramfs options</source>
        <translation>Izberite initramfs možnosti</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="451"/>
        <source>Select Item to Back Up</source>
        <translation>Izberite predmet za varnostno kopiranje</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="456"/>
        <source>Select Item to Restore</source>
        <translation>Izberite predmet, ki naj se obnovi</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="466"/>
        <location filename="../src/gui/mainwindow.cpp" line="477"/>
        <source>No location was selected.</source>
        <translation>Nobena lokacija ni bila izbrana.</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="471"/>
        <location filename="../src/gui/mainwindow.cpp" line="484"/>
        <source>Please select the root partition of the system you want to fix.</source>
        <translation>Izberite korenski (root) razdelek sistema, ki bi ga radi popravili.</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="489"/>
        <source>Select backup file name</source>
        <translation>Določite ime varostne kopije</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="491"/>
        <location filename="../src/gui/mainwindow.cpp" line="498"/>
        <source>No file was selected.</source>
        <translation>Nobena datoteka ni bila izbrana.</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="496"/>
        <source>Select MBR or PBR backup file</source>
        <translation>Izberite MBR ali PBR varnostno kopijo</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="514"/>
        <source>About %1</source>
        <translation>O %1</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="516"/>
        <source>Version: </source>
        <translation>Različica:</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="517"/>
        <source>Simple boot repair program for MX Linux</source>
        <translation>Preprost program za popravilo zagona v MX Linux</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="519"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="520"/>
        <source>%1 License</source>
        <translation>%1 licenca</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="533"/>
        <source>%1 Help</source>
        <translation>%1 pomoč</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/gui/about.cpp" line="52"/>
        <source>License</source>
        <translation>Licenca</translation>
    </message>
    <message>
        <location filename="../src/gui/about.cpp" line="53"/>
        <location filename="../src/gui/about.cpp" line="63"/>
        <source>Changelog</source>
        <translation>Dnevnik sprememb</translation>
    </message>
    <message>
        <location filename="../src/gui/about.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <location filename="../src/gui/about.cpp" line="73"/>
        <source>&amp;Close</source>
        <translation>&amp;Zapri</translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="86"/>
        <source>MX Boot Repair</source>
        <translation>MX popravilo zagona</translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="94"/>
        <source>MX Boot Repair - GUI and CLI tool for repairing GRUB bootloader</source>
        <translation>MX popravilo zagona -grafični vmesnik in orodje ukazne vrstice za popravilo GRUB zagonskega nalagalnika</translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="99"/>
        <source>Force CLI mode</source>
        <translation>Prisili v način ukazne vrstice</translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="100"/>
        <source>Print actions without executing</source>
        <translation>Izpiši dejanja brez izvedbe</translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="101"/>
        <source>Do not prompt; require flags</source>
        <translation>Bre opozoril; zahtevaj zastavice</translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="102"/>
        <source>Action: install, repair, initramfs, backup, restore</source>
        <translation>Action: install, repair, initramfs, backup, restore;dejanja, namestzitev, popravilo,kopije, obnovi</translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="103"/>
        <source>Target for install: mbr, esp, root</source>
        <translation>Cilj namestitve: mbr, esp, koren</translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="104"/>
        <source>Device for target (e.g., sda, sda1)</source>
        <translation>Ciljna naprava (npr. sda, sda1)</translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="105"/>
        <source>Root partition (e.g., /dev/sda2)</source>
        <translation>Korenski razdelek (npr. /dev/sda2)</translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="106"/>
        <source>Partition to mount at /boot in chroot</source>
        <translation>Razdelek za priklop na /boot v chroot</translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="107"/>
        <source>Partition to mount at /boot/efi in chroot</source>
        <translation>Razdelek za priklop na /boot/efi v chroot</translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="108"/>
        <source>Path for backup/restore image</source>
        <translation>Pot za varnostno kopiranje/obnovo</translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="109"/>
        <source>Skip confirmations (for restore)</source>
        <translation>Preskoči potrjevanje (za obnovo)</translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="110"/>
        <source>Enable verbose output</source>
        <translation>Vklopi podroben izpis</translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="111"/>
        <source>Suppress non-error output</source>
        <translation>Brez izpisa ne-napak</translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="121"/>
        <source>Error: --verbose and --quiet options are mutually exclusive
</source>
        <translation>Napaka: možnosti  --verbose in --quiet se medsebojno izključujeta</translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="127"/>
        <source>Error</source>
        <translation>Napaka</translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="128"/>
        <source>You must run this program with admin access.</source>
        <translation>Ta program je potrebno zagnati s skrbniškim dostopom</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="29"/>
        <source>Invalid index. Try again: </source>
        <translation>Neveljaven indeks. Poskusite znova:</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="48"/>
        <source>Invalid selection. Enter a number </source>
        <translation>Neveljavna izbira. Vnesite številko</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="234"/>
        <source>MX Boot Repair (CLI)</source>
        <translation>MX popravilo zagona (ukazna vrstica)</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="235"/>
        <source>1) Install GRUB</source>
        <translation>1) Namesti GRUB</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="236"/>
        <source>2) Repair GRUB (update-grub)</source>
        <translation>2) 2) Popravi GRUB (update-grub)</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="237"/>
        <source>3) Regenerate initramfs</source>
        <translation>3) Poustvari initramfs</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="238"/>
        <source>4) Backup MBR/PBR</source>
        <translation>4) Varnostno kopiraj MBR/PBR</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="239"/>
        <source>5) Restore MBR/PBR</source>
        <translation>5) Obnovi MBR/PBR</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="240"/>
        <source>q) Quit</source>
        <translation>q) Končaj</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="241"/>
        <source>Select action [1-5 or &apos;q&apos; to quit]: </source>
        <translation>Izberite dejanje [1-5 ali &apos;q&apos; za izhod]: </translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="247"/>
        <source>Invalid selection. Enter 1-5 or &apos;q&apos; to quit.</source>
        <translation>Neveljavna izbira Vnesite 1-5 ali &apos;q&apos; za izhod.</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="252"/>
        <source>Target: 0) MBR  1) ESP  2) Root</source>
        <translation>Cilj: 0) MBR  1) ESP  2) Koren</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="253"/>
        <source>Select target</source>
        <translation>Izberite cilj</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="259"/>
        <location filename="../src/cli/controller.cpp" line="297"/>
        <location filename="../src/cli/controller.cpp" line="310"/>
        <source>No partitions found. Returning to main menu.</source>
        <translation>Noben razdelek ni bil najden. Vrnitev v glavni meni.</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="263"/>
        <location filename="../src/cli/controller.cpp" line="323"/>
        <location filename="../src/cli/controller.cpp" line="341"/>
        <source>No disks found. Returning to main menu.</source>
        <translation>Noben disk ni bil najden. Vrnitev v glavni meni.</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="268"/>
        <source>Select disk for MBR (e.g., sda)</source>
        <translation>Izberite disk za MBR (npr. sda)</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="272"/>
        <source>Select partition for GRUB (e.g., sda1)</source>
        <translation>Izberite disk za GRUB (npr. sda1)</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="277"/>
        <source>Select root partition of installed system</source>
        <translation>Izberite korenski razdelek nameščenega sistema</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="298"/>
        <source>Select root partition to repair</source>
        <translation>Izberi korenski razdelek za popravilo</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="311"/>
        <source>Select root partition to regenerate initramfs</source>
        <translation>Izberi korenski razdelek za poustvaritev initramfs</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="324"/>
        <source>Select disk to back up MBR/PBR from</source>
        <translation>Izberite disk za varnostno kopijo MPR/PBR</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="327"/>
        <source>Output file path (or &apos;b&apos; to go back, &apos;q&apos; to quit): </source>
        <translation>Pot do izhodne datoteke (ali &apos;b&apos; za nazaj, &apos;q&apos; za izhod):</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="342"/>
        <source>Select disk to restore MBR/PBR to</source>
        <translation>Izberite disk za varnostno kopijo MPR/PBR</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="345"/>
        <source>Input backup file path (or &apos;b&apos; to go back, &apos;q&apos; to quit): </source>
        <translation>Pot do vhodne datoteke z varnostno kopijo (&apos;b&apos; za nazaj, &apos;q&apos; za izhod):</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="352"/>
        <source>WARNING: This will overwrite the first 446 bytes of /dev/</source>
        <translation>OPOZORILO: To bo prepisalo prvih 446 bajtov na /dev/</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="352"/>
        <source>. Continue? [y/N]: </source>
        <translation>. Nadaljujem? [d/N]: </translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="355"/>
        <source>yes</source>
        <comment>confirmation input: full word</comment>
        <translation>da</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="356"/>
        <source>y</source>
        <comment>confirmation input: single-letter yes</comment>
        <translation>d</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="360"/>
        <source>Cancelled.</source>
        <translation>Prekinjeno.</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="367"/>
        <source>Unknown selection</source>
        <translation>Neznana izbira</translation>
    </message>
</context>
</TS>